@@ -22,9 +22,7 @@
  * Author: Jaka Mocnik  <jaka@gnu.org>
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif /* HAVE_CONFIG_H */
+#include <config.h>
 
 #include <gio/gio.h>
 #include <glib/gi18n.h>
@@ -859,7 +857,7 @@ ghex_window_load(GHexWindow *win, const gchar *filename)
     gtk_widget_show(gh);
 
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-    gtk_container_set_border_width(GTK_CONTAINER(win), 4);
+    gtk_container_set_border_width(GTK_CONTAINER(vbox), 4);
     gtk_widget_show(vbox);
     gtk_box_pack_start(GTK_BOX(vbox), gh, TRUE, TRUE, 4);
 
